<?php
session_start(); // Start a session to access session variables

// Set an administrative password (hashed)
define('ADMIN_PASSWORD', password_hash('DemoPass', PASSWORD_DEFAULT)); // Change 'DemoPass' to your desired password
define('DATA_FILE', 'sites.json'); // Define the file for storing site data

// Load sites data from the JSON file
function loadSitesData() {
    if (file_exists(DATA_FILE)) {
        $jsonData = file_get_contents(DATA_FILE);
        return json_decode($jsonData, true);
    }
    return ['sites' => [], 'pending_sites' => []]; // Return empty arrays if the file does not exist
}

// Save sites data to the JSON file
function saveSitesData($data) {
    file_put_contents(DATA_FILE, json_encode($data));
}

$data = loadSitesData(); // Load existing data

// Check if the admin is logged in
if (!isset($_SESSION['logged_in'])) {
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['password'])) {
        // Validate the password
        if (password_verify($_POST['password'], ADMIN_PASSWORD)) {
            $_SESSION['logged_in'] = true; // Set the session variable to indicate the admin is logged in
        } else {
            $error = "Incorrect password. Please try again.";
        }
    }
}

// If not logged in, show the password form
if (!isset($_SESSION['logged_in'])) {
    if (isset($error)) {
        echo "<p style='color: red;'>$error</p>";
    }
    ?>
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>TopSite Script - Admin Login</title>
        <style>
            body {
                font-family: Arial, sans-serif;
                background-color: #fdfdfd;
                color: #333;
                margin: 0;
                padding: 20px;
            }
            header {
                text-align: center;
                background: #4CAF50;
                color: white;
                padding: 10px 0;
            }
            input[type="password"] {
                width: 70%;
                padding: 8px;
                margin-right: 10px;
            }
            button {
                background-color: #4CAF50;
                color: white;
                padding: 8px 15px;
                border: none;
                cursor: pointer;
            }
            button:hover {
                background-color: #45a049;
            }
        </style>
    </head>
    <body>
        <h2>Admin Login</h2>
        <form method="POST" action="admin.php">
            <input type="password" name="password" placeholder="Enter Admin Password" required />
            <button type="submit">Login</button>
        </form>
    </body>
    </html>
    <?php
    exit(); // Exit to prevent further execution of the code
}

// Handle site submissions from submit.php
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['new_site_name']) && isset($_POST['new_site_description'])) {
    $newSite = filter_var(trim($_POST['new_site_name']), FILTER_SANITIZE_URL);
    $description = htmlspecialchars(trim($_POST['new_site_description']), ENT_QUOTES, 'UTF-8');

    if (filter_var($newSite, FILTER_VALIDATE_URL)) {
        // Store it in pending sites
        $data['pending_sites'][] = ['url' => $newSite, 'description' => $description];
        saveSitesData($data); // Save after updating
    }
    // Redirect to see the updated list
    header('Location: admin.php');
    exit;
}

// Handle site approvals
if (isset($_POST['approve_site'])) {
    $siteToApprove = $_POST['approve_site'];
    // Find and move from pending to approved
    foreach ($data['pending_sites'] as $key => $site) {
        if ($site['url'] === $siteToApprove) {
            $data['sites'][] = $site;  // Add to approved sites
            unset($data['pending_sites'][$key]); // Remove from pending
            saveSitesData($data); // Save after updating
            break;
        }
    }
    // Redirect to see the updated list
    header('Location: admin.php');
    exit;
}

// Handle site removal from approved list
if (isset($_POST['remove_site'])) {
    $siteToRemove = $_POST['remove_site'];
    $data['sites'] = array_filter($data['sites'], function($site) use ($siteToRemove) {
        return $site['url'] !== $siteToRemove; // Compare URL in associative array
    });
    saveSitesData($data); // Save after updating
    // Redirect to see the updated list
    header('Location: admin.php');
    exit;
}

// Handle site edit
if (isset($_POST['edit_site'])) {
    $siteToEdit = $_POST['edit_site'];
    $newSiteUrl = filter_var(trim($_POST['edited_site_name']), FILTER_SANITIZE_URL);
    $newDescription = htmlspecialchars(trim($_POST['edited_site_description']), ENT_QUOTES, 'UTF-8');

    if (filter_var($newSiteUrl, FILTER_VALIDATE_URL)) {
        foreach ($data['sites'] as &$site) {
            if ($site['url'] === $siteToEdit) {
                $site['url'] = $newSiteUrl; // Update URL
                $site['description'] = $newDescription; // Update description
                break;
            }
        }
        saveSitesData($data); // Save after updating
    }
    // Redirect to see the updated list
    header('Location: admin.php');
    exit;
}

// The main admin panel layout starts here
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>TopSite Script - Admin Panel</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #fdfdfd;
            color: #333;
            margin: 0;
            padding: 20px;
        }
        header {
            text-align: center;
            background: #4CAF50;
            color: white;
            padding: 10px 0;
        }
        .admin-panel {
            margin-top: 20px;
            padding: 10px;
            border: 1px solid #4CAF50;
            background-color: #eeeeee;
            border-radius: 5px;
        }
        input[type="text"],
        input[type="password"] {
            width: 70%;
            padding: 8px;
            margin-right: 10px;
        }
        button {
            background-color: #4CAF50;
            color: white;
            padding: 8px 15px;
            border: none;
            cursor: pointer;
        }
        button:hover {
            background-color: #45a049;
        }
        .entry {
            margin: 10px 0;
        }
        .edit-entry, .pending-entry {
            margin: 5px 0;
        }
        .pending-entry {
            background-color: #fff3cd;
            padding: 10px;
            border: 1px solid #ffeeba;
            border-radius: 5px;
        }
    </style>
</head>
<body>

<header>
    <h1>TopSite Script - Admin Panel</h1>
</header>

<h3>Add New Site</h3>
<div class="admin-panel">
    <form method="POST" action="admin.php">
        <input type="text" id="siteName" name="new_site_name" placeholder="Enter site URL (e.g. http://example.com)" required />
        <input type="text" id="siteDescription" name="new_site_description" placeholder="Enter site description" required />
        <button type="submit">Add Site</button>
    </form>
</div>

<h3>Current Approved Sites</h3>
<div class="admin-panel">
    <?php
    // Display current approved sites
    if (!empty($data['sites'])) {
        foreach ($data['sites'] as $site) {
            echo "<div class='entry'>
                    <span>{$site['url']}</span><br>
                    <span>Description: {$site['description']}</span>
                    <form method='POST' action='admin.php' style='display:inline;'>
                        <input type='hidden' name='remove_site' value='{$site['url']}' />
                        <button type='submit'>Remove</button>
                    </form>
                    <form method='POST' action='admin.php' class='edit-entry' style='display:inline;'>
                        <input type='hidden' name='edit_site' value='{$site['url']}' />
                        <input type='text' name='edited_site_name' placeholder='New URL' value='{$site['url']}' required />
                        <input type='text' name='edited_site_description' placeholder='New description' value='{$site['description']}' required />
                        <button type='submit'>Edit</button>
                    </form>
                  </div>";
        }
    } else {
        echo "<p>No approved sites available.</p>";
    }
    ?>
</div>

<h3>Pending Approval Sites</h3>
<div class="admin-panel">
    <?php
    // Display pending sites
    if (!empty($data['pending_sites'])) {
        foreach ($data['pending_sites'] as $site) {
            echo "<div class='pending-entry'>
                    <span>{$site['url']}</span><br>
                    <span>Description: {$site['description']}</span>
                    <form method='POST' action='admin.php' style='display:inline;'>
                        <input type='hidden' name='approve_site' value='{$site['url']}' />
                        <button type='submit'>Approve</button>
                    </form>
                  </div>";
        }
    } else {
        echo "<p>No pending sites available.</p>";
    }
    ?>
</div>

</body>
</html>