<?php
session_start(); // Start a session to access session variables

define('DATA_FILE', 'sites.json'); // Define the filepath for storing site data

// Load existing sites from JSON file
function loadSitesData() {
    if (file_exists(DATA_FILE)) {
        $jsonData = file_get_contents(DATA_FILE);
        return json_decode($jsonData, true);
    }
    return ['pending_sites' => []]; // Return empty array if the file does not exist
}

// Save sites data to JSON file
function saveSitesData($data) {
    file_put_contents(DATA_FILE, json_encode($data, JSON_PRETTY_PRINT));
}

// Load data at the start
$data = loadSitesData();

// Initialize the session variable if not already
if (!isset($_SESSION['pending_sites'])) {
    $_SESSION['pending_sites'] = $data['pending_sites']; // Initialize from file if not set
}

// Handle approved sites
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['site_name']) && isset($_POST['site_description'])) {
    $newSite = filter_var(trim($_POST['site_name']), FILTER_SANITIZE_URL);
    $description = htmlspecialchars(trim($_POST['site_description']), ENT_QUOTES, 'UTF-8'); // Use htmlspecialchars for string sanitization

    if (filter_var($newSite, FILTER_VALIDATE_URL)) {
        // Store both the site URL and the description in an associative array
        $_SESSION['pending_sites'][] = ['url' => $newSite, 'description' => $description]; // Add the new site to the session

        // Also save to the JSON file
        saveSitesData(['pending_sites' => $_SESSION['pending_sites']]);
    }
    // Redirect to see the updated list of pending sites
    header('Location: submit.php');
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>TopSite Script - Submit a Site</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #fdfdfd;
            color: #333;
            margin: 0;
            padding: 20px;
        }
        header {
            text-align: center;
            background: #4CAF50;
            color: white;
            padding: 10px 0;
        }
        .submit-panel {
            margin-top: 20px;
            padding: 10px;
            border: 1px solid #4CAF50;
            background-color: #eeeeee;
            border-radius: 5px;
        }
        input[type="text"], textarea {
            width: 70%;
            padding: 8px;
            margin-right: 10px;
        }
        button {
            background-color: #4CAF50;
            color: white;
            padding: 8px 15px;
            border: none;
            cursor: pointer;
        }
        button:hover {
            background-color: #45a049;
        }
    </style>
</head>
<body>

<header>
    <h1>Submit Your Site</h1>
</header>

<div class="submit-panel">
    <form method="POST" action="">
        <input type="text" name="site_name" placeholder="Site URL" required>
        <textarea name="site_description" placeholder="Site Description" required></textarea>
        <button type="submit">Submit Site</button>
    </form>
</div>

</body>
</html>